@@ -30,9 +30,9 @@ dcor.ttest <- function(x, y, logged = FALSE) {
 
 
 #[export]
-dvar <- function(x, bc = FALSE) {
+dvar <- function (x, bc = FALSE) {
   if ( is.matrix(x) ) {
-    a <- .Call( Rfast_dvar, t(x), bc )
+    a <- .Call(Rfast_dvar, t(x), bc)
   } else {
     n <- length(x)
     i <- 1:n
@@ -40,9 +40,25 @@ dvar <- function(x, bc = FALSE) {
     sxi <- cumsum(x)
     sxn <- sxi[n]
     ai <- (2 * i - n) * x + sxn - 2 * sxi
-    D <- Rfast::Dist(x, square = TRUE, result = "sum")
-    a <- 2 * D/n^2 - 2/n^3 * sum(ai^2) + sum(ai)^2/n^4 
-    a <- sqrt(a)
+    #D <- Rfast::Dist(x, square = TRUE, result = "sum")
+    D <- n * sum(x^2) - sxn^2
+    if ( bc ) {
+      a <- 2 * D / ( n * (n - 3) ) - 2 / ( n * (n - 2) * (n - 3) ) * sum(ai^2) + 
+           sum(ai)^2 / (n * (n - 1) * (n - 2) * (n - 3) )
+    } else  a <- 2 * D/n^2 - 2/n^3 * sum(ai^2) + sum(ai)^2/n^4
+      a <- sqrt(a)
   }
-  a  
-}
\ No newline at end of file
+  a
+}
+
+
+
+#[export]
+pdcor <- function(x, y, z) {
+  a1 <- Rfast::dcor(x, y, bc = TRUE)$dcor
+  a2 <- Rfast::dcor(x, z, bc = TRUE)$dcor 
+  a3 <- Rfast::dcor(y, z, bc = TRUE)$dcor
+  up <- a1 - a2 * a3
+  down <- sqrt( 1 - a2^2 ) * sqrt( 1 - a3^2 )
+  up / down
+}
