@@ -10,4 +10,9 @@ sort_unique <- function(x) {
   }else{
   	.Call(Rfast_sort_unique_int,x)
   }
+}
+
+#[export]
+Unique <- function(x, fromLast = FALSE) {
+  .Call(Rfast_Unique,x,fromLast)
 }
\ No newline at end of file
