@@ -1,11 +1,8 @@
-// [[Rcpp::depends(RcppArmadillo)]]
-//[[Rcpp::plugins(cpp11)]]
-#include <RcppArmadillo.h>
+#define ARMA_64BIT_WORD
 #include <vector>
 #include <string>
 #include <algorithm>
 #include "mn.h"
-#include "Rfast.h"
 
 using namespace Rcpp;
 using namespace arma;
@@ -367,9 +364,9 @@ IntegerVector combine(IntegerVector x,IntegerVector y){
 }
 
 //dista
-arma::Col<int> get_k_indices(rowvec x,const int& k){
-  arma::Col<int> ind=linspace<arma::Col<int>>(1,x.size(),x.size());
-  std::sort(ind.begin(),ind.end(),[&](int i,int j){return x[i-1]<x[j-1];});
+Col<int> get_k_indices(rowvec x,const int& k){
+  Col<int> ind=linspace<Col<int>>(1,x.size(),x.size());
+  std::sort(ind.begin(),ind.end(),[&](Col<int>::elem_type i,Col<int>::elem_type j){return x[i-1]<x[j-1];});
   return ind(span(0,k-1));
 }
 
